Instructions for updating test data
===================================

Simply delete the corresponding reference directory from the
reference_data folder. Make sure you are on the correct <project>-data
branch before committing.
